@@ -223,12 +223,12 @@ class FacileToolkit2:
             if is_jquery_present:
                 self.wait_ajax_optional()
 
-        except TimeoutException as e:
-            if "renderer" in str(e.msg).lower():
-                self.sl.driver.refresh()
-                self.sl.wait_until_location_contains(url, timeout)
-            else:
-                self.sl.capture_page_screenshot(filename="EMBED")
+        # except TimeoutException as e:
+        #     if "renderer" in str(e.msg).lower():
+        #         self.sl.driver.refresh()
+        #         self.sl.wait_until_location_contains(url, timeout)
+        #     else:
+        #         self.sl.capture_page_screenshot(filename="EMBED")
         finally:
             self.sl.log_location()
 
